@@ -201,8 +201,8 @@ def get_server():
         - ``TIMEOUT`` --- timeout запроса к серверу ГАР в секундах.
         - ``USE_CACHE`` --- определяет необходимость кеширования HTTP-запросов
           к серверу m3-rest-gar. Значение по умолчанию: ``False``
-        - ``OAUTH2`` --- параметры OAuth2 (если не указан, то аутентификация
-          не используется):
+        - ``USE_SIMPLE_SERVER`` --- Использовать простой сервер, по умолчанию будет использоваться сервер OAUTH2
+        - ``OAUTH2`` --- параметры OAuth2: необходиы если не указано использовать простой сервер
 
           - ``TOKEN_URL`` --- Token endpoint URL, must use HTTPS.
           - ``CLIENT_ID``
@@ -217,7 +217,14 @@ def get_server():
     if settings.GAR.get('USE_CACHE', False):
         from django.core.cache import cache
 
-        if 'OAUTH2' in settings.GAR:  # pragma: no cover
+        if settings.GAR.get('USE_SIMPLE_SERVER', False):
+            result = SimpleCachingServer(
+                url=settings.GAR['URL'],
+                timeout=settings.GAR.get('TIMEOUT'),
+                cache=cache,
+            )
+
+        else:
             result = OAuth2CachingServer(
                 url=settings.GAR['URL'],
                 timeout=settings.GAR.get('TIMEOUT'),
@@ -229,15 +236,14 @@ def get_server():
                 password=settings.GAR['OAUTH2'].get('PASSWORD'),
             )
 
-        else:
-            result = SimpleCachingServer(
+    else:
+        if settings.GAR.get('USE_SIMPLE_SERVER', False):
+            result = SimpleServer(
                 url=settings.GAR['URL'],
                 timeout=settings.GAR.get('TIMEOUT'),
-                cache=cache,
             )
 
-    else:
-        if 'OAUTH2' in settings.GAR:  # pragma: no cover
+        else:
             result = OAuth2Server(
                 url=settings.GAR['URL'],
                 timeout=settings.GAR.get('TIMEOUT'),
@@ -248,12 +254,6 @@ def get_server():
                 password=settings.GAR['OAUTH2'].get('PASSWORD'),
             )
 
-        else:
-            result = SimpleServer(
-                url=settings.GAR['URL'],
-                timeout=settings.GAR.get('TIMEOUT'),
-            )
-
     return result
 
 
