@@ -596,11 +596,13 @@ def get_house(house_id, timeout=None):
     return result
 
 
-def find_house(house_number='', parent_id=None, timeout=None):
+def find_house(house_number='', parent_id=None, building_number=None, structure_number=None, timeout=None):
     """Возвращает информацию о здании по его номеру.
 
     :param unicode house_number: Номер дома.
     :param parent_id: ID родительского объекта.
+    :param unicode building_number: Номер корпуса.
+    :param unicode structure_number: Номер строения.
     :param float timeout: Timeout запросов к серверу ГАР в секундах.
 
     :rtype: m3_gar_client.data.House or NoneType
@@ -612,6 +614,13 @@ def find_house(house_number='', parent_id=None, timeout=None):
         timeout=timeout,
     ).load()
 
+    if len(houses) > 1:
+        _filter = lambda house: (
+            house['building_number'] == building_number and
+            house['structure_number'] == structure_number
+        )
+        houses = list(filter(_filter, houses))
+
     if len(houses) == 1:
         result = House(**houses[0])
     else:
