@@ -105,18 +105,21 @@ def get_address_object(obj_id, timeout=None):
     return config.backend.get_address_object(obj_id, timeout)
 
 
-def find_house(house_number='', parent_id=None, timeout=None):
+def find_house(house_number='', parent_id=None, building_number=None, structure_number=None, timeout=None):
     """Возвращает информацию о здании по его номеру.
 
     :param unicode house_number: Номер дома.
     :param parent_id: ID родительского объекта.
+    :param unicode building_number: Номер корпуса.
+    :param unicode structure_number: Номер строения.
+    :param parent_id: ID родительского объекта.
     :param float timeout: Timeout запросов к серверу ГАР в секундах.
 
     :rtype: m3_gar_client.data.House or NoneType
     """
     from m3_gar_client import config
 
-    return config.backend.find_house(house_number, parent_id, timeout)
+    return config.backend.find_house(house_number, parent_id, building_number, structure_number, timeout)
 
 
 def get_house(house_id, timeout=None):
